% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/header_replication.R
\name{run_mcstudy}
\alias{run_mcstudy}
\title{Run the Monte Carlo study by KLTG (2016), or a smaller version thereof}
\usage{
run_mcstudy(s = 2, a = 0.5, n = 12, nr_iterations = 50, zoom = FALSE,
  random_seed = 816)
}
\arguments{
\item{s, a, n}{Parameters characterizing the process from which data are simulated (see Section 4 and Table 4 of KLTG, 2016). Defaults to the values reported in the main text of the paper.}

\item{nr_iterations}{Number of Monte Carlo iterations (defaults to 50).}

\item{zoom}{Set to \code{TRUE} to produce results for a fine grid of small (MCMC) sample sizes, as in Figure 2 of KLTG (2016).}

\item{random_seed}{Seed used for running the simulation experiment. Defaults to 816.}
}
\value{
Object of class "mcstudy", containing the results of the analysis. This object can be passed to \code{plot} for plotting, see the documentation for \link{plot.mcstudy}.
}
\description{
Run the Monte Carlo study by KLTG (2016), or a smaller version thereof
}
\details{
The full results in Section 4 of KLTG (2016) are based on \code{s = 2}, \code{a = 0.5},
\code{n = 12} and \code{nr_iterations = 1000}. Producing these results takes about 140 minutes on an 
Intel i7 processor.
}
\author{
Fabian Krueger
}
\references{
Krueger, F., S. Lerch, T.L. Thorarinsdottir and T. Gneiting (2016), `Probabilistic forecasting and comparative model assessment based on Markov Chain Monte Carlo output', working paper, Heidelberg Institute for Theoretical Studies, available at \url{http://arxiv.org/abs/1608.06802}.
}
\seealso{
\link{plot.mcstudy} produces a summary plot of the results generated by \link{run_mcstudy}
}
\keyword{replication}

